@@ -1,8 +1,10 @@
 from __future__ import annotations
 
-from fastapi import APIRouter, Response, status
+from fastapi import Response, status
 from sqlalchemy import text
 
+from svc_infra.api.fastapi import DualAPIRouter
+
 from .session import SqlSessionDep
 
 
@@ -10,14 +12,14 @@ def _make_db_health_router(
     *,
     prefix: str = "/_sql/health",
     include_in_schema: bool = False,
-) -> APIRouter:
+) -> DualAPIRouter:
     """Internal factory for the DB health router."""
-    r = APIRouter(prefix=prefix, tags=["health"], include_in_schema=include_in_schema)
+    router = DualAPIRouter(prefix=prefix, tags=["health"], include_in_schema=include_in_schema)
 
-    @r.get("", status_code=status.HTTP_200_OK)
+    @router.get("", status_code=status.HTTP_200_OK)
     async def db_health(session: SqlSessionDep) -> Response:
         # Execute a trivial query to ensure DB/connection pool is alive.
         await session.execute(text("SELECT 1"))
         return Response(status_code=status.HTTP_200_OK)
 
-    return r
+    return router
