@@ -1,18 +1,20 @@
+from svc_infra.cli.cmds.cache.redis.redis_cmds import register as register_redis
 from svc_infra.cli.cmds.db.nosql.mongo.mongo_cmds import register as register_mongo
 from svc_infra.cli.cmds.db.nosql.mongo.mongo_scaffold_cmds import (
     register as register_mongo_scaffold,
 )
 from svc_infra.cli.cmds.db.sql.alembic_cmds import register as register_alembic
 from svc_infra.cli.cmds.db.sql.sql_scaffold_cmds import register as register_sql_scaffold
+from svc_infra.cli.cmds.obs.obs_cmds import register as register_obs
 
 from .help import _HELP
-from .obs_cmds import register as register_obs
 
 __all__ = [
     "register_alembic",
     "register_sql_scaffold",
-    "register_obs",
     "register_mongo",
     "register_mongo_scaffold",
+    "register_redis",
+    "register_obs",
     "_HELP",
 ]
